@@ -88,6 +88,9 @@ export CLEANUP="echo All done!"
 
 # Download first package
 
+echo " "
+echo "Downloading $PKGNAME1 package..."
+
 export GOTIT="no"
 
 if [ -f $TARPATH/$BIGTAR1 ] ; then
@@ -98,9 +101,6 @@ if [ -f $TARPATH/$BIGTAR1 ] ; then
   fi
 fi
 
-echo " "
-echo "Downloading $PKGNAME1 package..."
-
 export GOOD=1
 export TEST=2
 
@@ -136,6 +136,9 @@ This could take a very long time and could\n\
 cause your device to become unresponsive."`
      gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0 -geometry 640x250 -title "Decompressing" "$MSG1" &
 
+     echo " "
+     echo "Extracting $BIGTAR1 package..."
+
      TARERR="Unknown lzma error"
      # read -p 'press enter' key
      #$TARCMD1
